@@ -16,11 +16,12 @@
 
 use crate::{difficulty::bitcoin_retarget, error::ConsensusError, MerkleTreeLedger};
 use snarkos_profiler::{end_timer, start_timer};
-use snarkvm_algorithms::{CRH, SNARK};
+use snarkvm_algorithms::SNARK;
 use snarkvm_curves::bls12_377::Bls12_377;
 use snarkvm_dpc::{
-    testnet1::{instantiated::*, program::NoopProgram, BaseDPCComponents},
+    testnet1::instantiated::*,
     BlockHeader,
+    DPCComponents,
     DPCScheme,
     MerkleRootHash,
     Network,
@@ -29,10 +30,10 @@ use snarkvm_dpc::{
     Storage,
 };
 use snarkvm_posw::{Marlin, PoswMarlin};
-use snarkvm_utilities::{to_bytes, FromBytes, ToBytes};
+use snarkvm_utilities::FromBytes;
 
 use chrono::Utc;
-use rand::Rng;
+use rand::{CryptoRng, Rng};
 
 pub const TWO_HOURS_UNIX: i64 = 7200;
 
@@ -111,7 +112,7 @@ impl ConsensusParameters {
         }
 
         // Verify the proof
-        let proof = <Marlin<Bls12_377> as SNARK>::Proof::read(&header.proof.0[..])?;
+        let proof = <Marlin<Bls12_377> as SNARK>::Proof::read_le(&header.proof.0[..])?;
         let verification_timer = start_timer!(|| "POSW verify");
         self.verifier
             .verify(header.nonce, &proof, &header.pedersen_merkle_root_hash)?;
@@ -123,54 +124,19 @@ impl ConsensusParameters {
     // TODO (raychu86): Genericize this model to allow for generic programs.
     /// Generate the birth and death program proofs for a transaction for a given transaction kernel
     #[allow(clippy::type_complexity)]
-    pub fn generate_program_proofs<R: Rng, S: Storage>(
-        parameters: &<InstantiatedDPC as DPCScheme<MerkleTreeLedger<S>>>::NetworkParameters,
-        transaction_kernel: &<InstantiatedDPC as DPCScheme<MerkleTreeLedger<S>>>::TransactionKernel,
+    pub fn generate_program_proofs<R: Rng + CryptoRng, S: Storage>(
+        dpc: &Testnet1DPC,
+        transaction_kernel: &<Testnet1DPC as DPCScheme<MerkleTreeLedger<S>>>::TransactionKernel,
         rng: &mut R,
-    ) -> Result<
-        (
-            Vec<<InstantiatedDPC as DPCScheme<MerkleTreeLedger<S>>>::PrivateProgramInput>,
-            Vec<<InstantiatedDPC as DPCScheme<MerkleTreeLedger<S>>>::PrivateProgramInput>,
-        ),
-        ConsensusError,
-    > {
+    ) -> Result<Vec<<Testnet1DPC as DPCScheme<MerkleTreeLedger<S>>>::Execution>, ConsensusError> {
         let local_data = transaction_kernel.into_local_data();
 
-        let noop_program_snark_id = to_bytes![ProgramVerificationKeyCRH::hash(
-            &parameters.system_parameters.program_verification_key_crh,
-            &to_bytes![parameters.noop_program_snark_parameters.verification_key]?
-        )?]?;
-
-        let dpc_program =
-            NoopProgram::<_, <Components as BaseDPCComponents>::NoopProgramSNARK>::new(noop_program_snark_id);
-
-        let mut old_death_program_proofs = Vec::with_capacity(NUM_INPUT_RECORDS);
-        for i in 0..NUM_INPUT_RECORDS {
-            let private_input = dpc_program.execute(
-                &parameters.noop_program_snark_parameters.proving_key,
-                &parameters.noop_program_snark_parameters.verification_key,
-                &local_data,
-                i as u8,
-                rng,
-            )?;
-
-            old_death_program_proofs.push(private_input);
+        let mut program_proofs = Vec::with_capacity(Components::NUM_TOTAL_RECORDS);
+        for position in 0..Components::NUM_TOTAL_RECORDS {
+            program_proofs.push(dpc.noop_program.execute(&local_data, position as u8, rng)?);
         }
 
-        let mut new_birth_program_proofs = Vec::with_capacity(NUM_OUTPUT_RECORDS);
-        for j in 0..NUM_OUTPUT_RECORDS {
-            let private_input = dpc_program.execute(
-                &parameters.noop_program_snark_parameters.proving_key,
-                &parameters.noop_program_snark_parameters.verification_key,
-                &local_data,
-                (NUM_INPUT_RECORDS + j) as u8,
-                rng,
-            )?;
-
-            new_birth_program_proofs.push(private_input);
-        }
-
-        Ok((old_death_program_proofs, new_birth_program_proofs))
+        Ok(program_proofs)
     }
 }
 
